==> haskell-hspec-wai-0.11.1-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-9izCg5gUd2CBywa35y39hl
key:                  hspec-wai-0.11.1-9izCg5gUd2CBywa35y39hl
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  0d7c5b02054d7507b205c519b120a9e4
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-9izCg5gUd2CBywa35y39hl
depends:
    QuickCheck-2.14.2-8zyY9zXCBqJEtGUr0EcOS8 base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve bytestring-0.10.12.1
    case-insensitive-1.2.1.0-6kJrtrIbTbo7OQo00pesxa
    hspec-core-2.9.4-61RwZJac8zZJK2zvkhrEDW
    hspec-expectations-0.8.2-6qi8cjonJ6NDcZGGp2xU9X
    http-types-0.12.3-4gBfONCvvNM58oU4i771Nd text-1.2.5.0
    transformers-0.5.6.2 wai-3.2.3-KIShmmcdzpMKtYStiSbX8d
    wai-extra-3.1.8-FRLD4lZ5OJwGi4wrKHyWVN

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.11.1-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-DNslvvCiGM93fiLcAfnpcC
key:                  hspec-wai-0.11.1-DNslvvCiGM93fiLcAfnpcC
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  5a90e0e28dadfe2a9b7da50e49887f7d
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-DNslvvCiGM93fiLcAfnpcC
depends:
    QuickCheck-2.14.2-2d1sNWCQrBtBwhjNiSfZuE base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve bytestring-0.10.12.1
    case-insensitive-1.2.1.0-5VDT8fH2EuK8lxYh6ZMoM9
    hspec-core-2.9.5-6Hs99hJqVE7JtCjqJ3AiRp
    hspec-expectations-0.8.2-6qi8cjonJ6NDcZGGp2xU9X
    http-types-0.12.3-2e38dQdIZwj3mYWK3wvdKY text-1.2.5.0
    transformers-0.5.6.2 wai-3.2.3-9gPQUpOP3Jh3Qx2YJlS50v
    wai-extra-3.1.8-LChCTJQ6U8YLKkaxNcU4he

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
